/// <reference types="react" />
import { DropdownMenuProps } from '../selector/dropdown-menu';
import { UkeComponent } from '../utils/uke-component';
import { Color } from '../utils/props';
interface TitleFormSelector extends DropdownMenuProps {
    /** 如果为 type === selector，则渲染 DropdownMenu，其余属性传入 DropdownMenu 组件 */
    type?: 'selector' | string;
    ref?: string;
}
declare type FuncTitle = (item: any, idx: any) => any;
export interface KeyMapperItem {
    /** 对应 record 数据的 [key] */
    key: string;
    /** 处理对应 Row 的 filter */
    filter?: (contentResult: any, record: any, mapper: any, rowIdx: any) => any;
    /** */
    title?: string | FuncTitle | TitleFormSelector;
    /** 是否渲染为 date 格式 - YYYY-MM-DD */
    date?: boolean;
    /** 是否渲染为 datetime 格式 - YYYY-MM-DD hh:mm:ss */
    datetime?: boolean;
    /** 是否做金额格式化 */
    money?: boolean;
    /** 是否格式为绝对值的金额 */
    abvMoney?: boolean;
    /** 是否统计该 Row */
    count?: boolean;
    /** 是否可选择 */
    selectable?: boolean;
    /** 是否统计该 Row */
    tips?: string | string[];
    /** 渲染让对应 dataSrc 的数据嵌入 Label */
    labels?: {
        [dataKey: string]: Color;
    };
    /** 内置的 字段映射 过滤器 */
    namesMapper?: {
        [dataSrc: string]: string;
    };
    /** 是否固定 */
    fixed?: 'left' | 'right';
}
export interface RecordItem {
    [key: string]: any;
}
export declare type Records = RecordItem[];
export declare type KeyMapper = KeyMapperItem[];
export interface MapperFilterProps {
    keyMapper: KeyMapper;
    /** 服务端返回的数据 */
    records?: Records;
    onChange?: (val: any, title: any) => void;
    /** 右边固定表格的列的集合 */
    fixedRightKeys?: string[];
    /** 左边固定表格的列的集合 */
    fixedLeftKeys?: string[];
}
declare const excludeKey: (target: any, keys: any) => any;
export default class MapperFilter<P = MapperFilterProps, S = {}> extends UkeComponent<P & MapperFilterProps, S> {
    /** 可以覆盖的 excludeKeys */
    excludeKeys: string[];
    sortIgnores: string[];
    selectorCache: {};
    scrollX: number;
    scrollY: number;
    onChangeRecords: any;
    shouldComponentUpdate(nextProps: any, nextState: any, nextContext: any): boolean;
    isInFixedTable: (key: any) => boolean;
    titleFilter(item: any, idx: any): JSX.Element;
    /**
     * mapperFilter 字段过滤器处理顺序
     *
     * 1. date || datetime || money || abvMoney
     * 2. labels && namesMapper
     * 3. filter
     */
    mapperFilter: (mapper: any, record: any, rowIdx?: any) => any;
}
export { excludeKey };
